@@ -7,7 +7,7 @@
 #'
 #' If argument \code{S} is a single column vector with indices \code{1:N}, then
 #' \code{rowAvgsPerColSet(X, S = S, FUN = rowMeans)} gives the same result as
-#' \code{rowMeans(X)}.  Analogously, for \code{rowAvgsPerColSet()}.
+#' \code{rowMeans(X)}.  Analogously, for \code{colAvgsPerRowSet()}.
 #'
 #' @param X A \code{\link[base]{numeric}} NxM \code{\link[base]{matrix}}.
 #'
@@ -122,14 +122,22 @@ rowAvgsPerColSet <- function(X, W = NULL, rows = NULL, S,
     }
 
     # Sanity check
-    stopifnot(length(Zjj) == dimX[1L])
+    if (length(Zjj) != dimX[1L]) stop("Internal error: length(Zjj) != dimX[1L]")
 
     # Return set average
     Zjj
   })
 
+  # apply() drops 2nd dimension if nrow(X) <= 1 (and FUN returns a vector of
+  # length nrow(X) as it should), cf. ?apply
+  if (!is.matrix(Z)) {
+    if (dimX[1] > 1L) stop("Internal error: dimX[1] > 1L")
+    dim(Z) <- c(length(Z), nbrOfSets)
+  }
+
   # Sanity check
-  stopifnot(dim(Z) == c(dimX[1L], nbrOfSets))
+  if (any(dim(Z) != c(dimX[1L], nbrOfSets)))
+    stop("Internal error: dim(Z) != c(dimX[1L], nbrOfSets)")
 
   # Set names
   rownames(Z) <- rownamesX
@@ -141,7 +149,7 @@ rowAvgsPerColSet <- function(X, W = NULL, rows = NULL, S,
 #' @rdname rowAvgsPerColSet
 #' @export
 colAvgsPerRowSet <- function(X, W = NULL, cols = NULL, S,
-                             FUN = colMeans, tFUN = FALSE, ...) {
+                             FUN = colMeans, ..., tFUN = FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -183,7 +191,7 @@ colAvgsPerRowSet <- function(X, W = NULL, cols = NULL, S,
   }
 
   # ...
-  tZ <- rowAvgsPerColSet(X = tX, W = tW, S = S, FUN = FUN, tFUN = !tFUN, ...)
+  tZ <- rowAvgsPerColSet(X = tX, W = tW, S = S, FUN = FUN, ..., tFUN = !tFUN)
   tX <- tW <- NULL  # Not needed anymore
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
